==> etchibbs-spiral-1.0.0.tar.gz: etchibbs-spiral/search.php <==
<?php
/* vim600: et ts=4 sts=4 sw=4 fdm=marker
 *
 * EtchiBBS UTF-8 - Gallery Web Board
 * Copyright (C) 2004 EtchiBoard Project
 * 
 * See LICENSE for license condition.
 *
 * http://etchibbs.kldp.net
 * $Id: search.php,v 1.13 2004/01/22 03:17:17 lseeker Exp $
 */

require 'lib/admin.inc'; // 관리자 환경설정
include 'lib/headfoot.inc'; // 상/하단부
include 'lib/list.inc'; // 글 목록 function
include 'lib/message.inc'; // 메시지 function

PrintHeader(); // 헤더 출력

# 현재 페이지 구하기 (넘겨진 변수 포함)

/* XXX 분기가 필요한가? */
$page_this = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : $_SERVER['PHP_SELF'] . '?' . $_SERVER['QUERY_STRING'];

$page_this = rawurlencode(str_replace('&', '%26', $page_this));

if(empty($_GET['search_word'])) {
    PrintMessage("검색어를 입력해 주세요.", "error");
    PrintFooter();
    exit;
/* FIXME UTF-8에서는 비적합. 한글 하나가 3바이트인지라... ==3
} elseif (strlen($_GET['search_word']) < 4) {
    PrintMessage("검색어가 너무 짧습니다.<br>검색어는 영문 4자, 한글 2자 이상이어야 합니다.", "error");
    PrintFooter();
    exit;
*/
} else {
    $search_type = $_GET['search_type']; /* PrintArticle을 위해 필요 */
    if (!strcmp($search_type, 'name')) $search_type_str = "작성자";
    elseif (!strcmp($search_type, 'subject')) $search_type_str = '글 제목';
    elseif (!strcmp($search_type, 'ment')) $search_type_str = '글 내용';
    else $search_type_str = '파일 이름';
    if (!get_magic_quotes_gpc()) $_GET['search_word'] = addslashes($_GET['search_word']);
    $search_word = str_replace("%", "\%", $_GET['search_word']); // % 교체
}

// 역순으로 정렬하고 $result까지 for 돌려서 idx를 search_residx 배열에 처넣기.
$search_sock = &DB::query("SELECT idx FROM hboard_db_article
        WHERE {$_GET['search_type']} like '%{$search_word}%' AND deleted='f' ORDER BY idx DESC",
        $dbconn) or die(PrintMessage("검색 오류입니다. DB를 확인해 주세요.", "error"));

$fileidx = &DB::numrows($search_sock);

/* XXX ??? */
// % 검색어는 다시 원래대로.. (...응?;)
$search_word = str_replace("\%", "%", $search_word);

for($i=0; $i<=($fileidx-1); $i++) {
    $search_residx[] = &DB::result($search_sock, $i, "idx");
}

DB::close($dbconn);

## 페이지 확인 부분
$page = empty($_GET['page']) ? 1 : $_GET['page']; // 입력받지 않았으면, 자동으로 1로 설정하기

# 읽어들인 인덱스를 이용해 페이지 넘기기
$startpage = sprintf("%d", $fileidx/$admin_data['app']+0.99); // 페이지 수 -_-
if($startpage < 1) $startpage = 1;

$footart = ($admin_data['app']*$page) - 1; // 현재 페이지의 최하단 게시물
$headart = $footart - ($admin_data['app'] - 1); // 현재 페이지의 최상단 게시물

if($page < 0) PrintMessage("페이지가 지정된 범위를 초과했습니다.", "error");
else if($page > $startpage) PrintMessage("페이지가 지정된 범위를 초과했습니다.", "error");
else {
?>
<script type="text/javascript">
<!--
function checksearch() {
    if(document.searchform.search_word.value == ""){
        alert("검색어를 입력해 주세요.");
        document.searchform.search_word.focus();
        return true;
    }
    else {
        document.searchform.submit();
    }
}

function Openwindow(name, url, left, top, width, height, toolbar, menubar, statusbar, scrollbar, resizable)
// script from Namo Webeditor
{
  toolbar_str = toolbar ? 'yes' : 'no';
  menubar_str = menubar ? 'yes' : 'no';
  statusbar_str = statusbar ? 'yes' : 'no';
  scrollbar_str = scrollbar ? 'yes' : 'no';
  resizable_str = resizable ? 'yes' : 'no';
  window.open(url, name, 'left='+left+',top='+top+',width='+width+',height='+height+',toolbar='+toolbar_str+',menubar='+menubar_str+',status='+statusbar_str+',scrollbars='+scrollbar_str+',resizable='+resizable_str);
}
//-->
</script>
<center>

<table align="center" width="90%" cellpadding="0" cellspacing="0" bgcolor="<?php echo $skin['image_table_bgcolor']; ?>">
<tr><td width="37">
<p align="center"><span style="font-size:9pt;">
<img src="skin/<?php echo $admin_data['skin']; ?>/info.jpg" width="32" height="32" alt="Info"></span></p>
</td>
<td>
<p><span style="font-size:9pt;"><?php echo $search_type_str; ?>에 대한 검색어 <b><?php echo $search_word; ?></b>(으)로 <b><?php echo $fileidx; ?></b>개의 결과가 검색되었습니다. <b><a href="list.php">[목록으로 돌아가기]</a></b><br>현재 <?php echo $page; ?> 페이지 / 전체&nbsp;<?php echo $startpage; ?>&nbsp;페이지 (페이지당 <?php echo $admin_data['app']?>개씩 출력)</span></p>
</td>

<td width="37">
<p><span style="font-size:9pt;"><a href="#search"><img src="skin/<?php echo $admin_data['skin']?>/search.jpg" width="32" height="32" alt="검색" border="0"></a></span></p>
</td>

<?php
/* {{{ 관리자 로그인 상태 처리부분 */ 
    if ($admin['login']) {
?>

<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_config', 'config.php?from=<?php echo $page_this?>', 30, 30, 700, 610, 0, 0, 0, 1, 1)"><img src="skin/<?php echo $admin_data['skin']; ?>/config.jpg" width="32" height="32" alt="게시판 환경 설정" border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_iconman', 'iconman.php', 60, 60, 610, 400, 0, 0, 0, 1, 1)"><img src="skin/<?php echo $admin_data['skin']; ?>/addicon.jpg" width="32" height="32" alt="아이콘 관리자" border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="admin_logout.php?from=<?php echo str_replace('%2526', '%26', $page_this); ?>"><img src="skin/<?php echo $admin_data['skin']; ?>/logout.jpg" width="32" height="32" alt="관리자 로그아웃" border="0"></a></span></p>
</td>

<?php } else { ?>

<td width="37">
 <p>
 <a href="javascript:Openwindow('hb_login', 'admin.php?from=<?php echo $page_this;?>', 50, 50, 360, 80, 0, 0, 0, 0, 0);"
  title="관리자 로그인"><img src="skin/<?php echo $admin_data['skin'];?>/login.jpg"
  width="32" height="32" alt="관리자 로그인" border="0"></a>
 </p>
</td>

<?php } /* }}} */ ?>

</tr></table>
<br>
<!-- {{{ 출력부분 시작 -->
<?php

    if($fileidx<=0) {
        echo "<center><br><font size=5>검색된 데이터가 없습니다.</font><br><br></center>\n";
    }
    else {

        // 아 쒸x.... 검색하면 idx가 순차적으로 있는게 아니군 -_-;;
        // 하는수없이 검색하면 과부하가 조금... -_-^
        for($i=$headart; $i<=$footart; $i++) {
            if(isset($search_residx[$i])) {
                PrintArticle($search_residx[$i], $search_residx[$i], true);
            }
        }

    }

    echo "현재 <b><font color=blue>" .$page ."</font></b> 페이지 <font color=green>/</font> 전체 <b><font color=red>" .$startpage ."</font></b> 페이지<br>";

    if($page>1) {
        echo "<a href=\"search.php?page=1&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\" title=\"첫 페이지\">|</a>&nbsp;<a href=\"search.php?page=" . $page - 1 . "&amp;search_word={$search_word}&amp;search_type={$search_type}\" title=\"이전 페이지\">◁</a>&nbsp;&nbsp;";
    } else {
        echo "<font color=\"{$skin['image_table_bgcolor']}\"><a title=\"첫 페이지\">|</a>&nbsp;<a title=\"이전 페이지\">◁</a></font>&nbsp;&nbsp;";
    } // 이전 페이지랑 첫 페이지 버튼

    // 미친 for문 부분 시작
    for($pagecnt=($page-4);; $pagecnt++) {
        if($pagecnt<=0) { } // 페이지가 처음이면 do nothing;
        else if($pagecnt>=$page) {
            break; }
            else {
                echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\">[" .$pagecnt ."]</a>&nbsp;"; }
            }

            echo "[<b>" .$page ."</b>]&nbsp;";

            for($pagecnt=($page+1);; $pagecnt++) {

                if($page<=4) { // 첫 페이지라면?
                if($pagecnt>$startpage) { break; } // 끝에 닿으면 정지
                else if($pagecnt>=(($page+10)-$page)) { break; }
                else { echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\">[" .$pagecnt ."]</a>&nbsp;"; }
            }

            else { // 아님 말구 ㅡㅡ..
            if($pagecnt>$startpage) { break; } // 끝에 닿으면 정지
            else if($pagecnt>=($page+5)) { break; } // +5 도 정지
            else { echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\">[" .$pagecnt ."]</a>&nbsp;"; }
        }
    }

    // 미친 for문 부분 끝

    if(($fileidx/$page)<=$admin_data['app']) {
        echo "&nbsp;<font color=\"{$skin['image_table_bgcolor']}\"><a title=\"다음 페이지\">▷</a>&nbsp;<a title=\"마지막 페이지\">|</a></font>";
    } else {
        echo "&nbsp;<a href=\"search.php?page=" .($page+1) ."&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\" title=\"다음 페이지\">▷</a>&nbsp;<a href=\"search.php?page=" .$startpage ."&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\" title=\"마지막 페이지\">|</a>";
    } // 다음 페이지랑 마지막 페이지 버튼..ㅡㅡ

    // 검색폼에서 미리 선택된 검색방식..
    /* E_NOTICE 처리 */
    $option['name'] = $option['subject'] = $option['ment'] = $option['cfile'] = '';

    if($_GET['search_type'] == "name") $option['name'] = " selected";
    else if($_GET['search_type'] == "subject") $option['subject'] = " selected";
    else if($_GET['search_type'] == "ment") $option['ment'] = " selected";
    else $option['cfile'] = " selected";
?>
<br>
<a name="search"></a>
<form name="searchform" action="search.php" method="get">
 <table width="314" align="center" cellpadding="0" cellspacing="0" bgcolor="<?php echo $skin['image_table_bgcolor']; ?>">
  <tr>
   <td width="18" height="37">
    <p align="center">
    <span style="font-size:9pt;">&nbsp;</span></p>
   </td>
   <td width="56" height="37">
    <p align="center">
    <span style="font-size:9pt;"><img src="skin/<?php echo $admin_data['skin']; ?>/search.jpg" width="32" height="32" alt="검색" border="0"></span></p>
   </td>
   <td width="79" height="37">
    <p align="center"><span style="font-size:9pt;">
     <select name="search_type" size="1">
      <option value="name"<?php echo $option['name']; ?>>작성자</option>
      <option value="subject"<?php echo $option['subject']; ?>>글 제목</option>
      <option value="ment"<?php echo $option['ment']; ?>>글 내용</option>
      <option value="cfile"<?php echo $option['cfile']; ?>>파일 이름</option>
    </select></span></p>
   </td>
   <td width="120" height="37">
    <p align="center"><span style="font-size:9pt;"><input type="text" name="search_word" maxlength="50" size="15" value="<?php echo $search_word; ?>"></span></p>
   </td>
   <td width="50" height="37">

    <p align="left">&nbsp;<span style="font-size:9pt;"><input type="button" name="search_go" value="검색" onclick="checksearch();"></span>
   </td>
   <td width="15" height="37">
    <p><span style="font-size:9pt;">&nbsp;</span></p>

   </td>
  </tr>
 </table>
</form>
<b><a href="list.php">[◁ 목록으로 돌아가기]</a></b>
<br>
<br>

<!-- }}} 출력부분 끝 -->

<?php
}
PrintFooter();
?>

==> etchibbs-spiral-1.0.3.tar.gz: etchibbs-spiral/search.php <==
<?php
/* vim600: et ts=4 sts=4 sw=4 fdm=marker
 *
 * EtchiBBS UTF-8 - Gallery Web Board
 * Copyright (C) 2004 EtchiBoard Project
 * 
 * See LICENSE for license condition.
 *
 * http://etchibbs.kldp.net
 * $Id: search.php,v 1.13.2.7 2004/02/23 07:53:31 lseeker Exp $
 */

require 'lib/admin.inc'; // 관리자 환경설정
include 'lib/headfoot.inc'; // 상/하단부
include 'lib/list.inc'; // 글 목록 function
include 'lib/message.inc'; // 메시지 function

PrintHeader(); // 헤더 출력

# 현재 페이지 구하기 (넘겨진 변수 포함)

/* XXX 분기가 필요한가? */
$page_this = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : $_SERVER['PHP_SELF'] . '?' . $_SERVER['QUERY_STRING'];

$page_this = rawurlencode(rawurlencode($page_this));

if(empty($_GET['search_word'])) {
    PrintMessage("검색어를 입력해 주세요.", "error");
    PrintFooter();
    exit;
/* FIXME UTF-8에서는 비적합. 한글 하나가 3바이트인지라... ==3
} elseif (strlen($_GET['search_word']) < 4) {
    PrintMessage("검색어가 너무 짧습니다.<br>검색어는 영문 4자, 한글 2자 이상이어야 합니다.", "error");
    PrintFooter();
    exit;
*/
} else {
    $search_type = $_GET['search_type']; /* PrintArticle을 위해 필요 */
    if (!strcmp($search_type, 'name')) $search_type_str = "작성자";
    elseif (!strcmp($search_type, 'subject')) $search_type_str = '글 제목';
    elseif (!strcmp($search_type, 'ment')) $search_type_str = '글 내용';
    else $search_type_str = '파일 이름';
    if (!get_magic_quotes_gpc()) $_GET['search_word'] = addslashes($_GET['search_word']);
    $search_word = str_replace('%', '\\\\%', $_GET['search_word']); // % 교체
}

// 역순으로 정렬하고 $result까지 for 돌려서 idx를 search_residx 배열에 처넣기.
$search_sock = &DB::query("SELECT idx FROM hboard_db_article
        WHERE {$_GET['search_type']} like '%{$search_word}%' AND deleted='f' ORDER BY idx DESC",
        $dbconn) or die(PrintMessage("검색 오류입니다. DB를 확인해 주세요.", "error"));

$fileidx = &DB::numrows($search_sock);

/* XXX ??? */
// % 검색어는 다시 원래대로.. (...응?;)
$search_word = str_replace('\\\\%', '%', $search_word);

for($i=0; $i<=($fileidx-1); $i++) {
    $search_residx[] = &DB::result($search_sock, $i, "idx");
}

DB::close($dbconn);

## 페이지 확인 부분
$page = empty($_GET['page']) ? 1 : $_GET['page']; // 입력받지 않았으면, 자동으로 1로 설정하기

# 읽어들인 인덱스를 이용해 페이지 넘기기
$startpage = sprintf("%d", $fileidx/$admin_data['app']+0.99); // 페이지 수 -_-
if($startpage < 1) $startpage = 1;

$footart = ($admin_data['app']*$page) - 1; // 현재 페이지의 최하단 게시물
$headart = $footart - ($admin_data['app'] - 1); // 현재 페이지의 최상단 게시물

if($page < 0) PrintMessage("페이지가 지정된 범위를 초과했습니다.", "error");
else if($page > $startpage) PrintMessage("페이지가 지정된 범위를 초과했습니다.", "error");
else {
?>
<script type="text/javascript">
<!--
function checksearch() {
    if(document.searchform.search_word.value == ""){
        alert("검색어를 입력해 주세요.");
        document.searchform.search_word.focus();
        return true;
    }
    else {
        document.searchform.submit();
    }
}

function Openwindow(name, url, left, top, width, height, toolbar, menubar, statusbar, scrollbar, resizable)
// script from Namo Webeditor
{
  toolbar_str = toolbar ? 'yes' : 'no';
  menubar_str = menubar ? 'yes' : 'no';
  statusbar_str = statusbar ? 'yes' : 'no';
  scrollbar_str = scrollbar ? 'yes' : 'no';
  resizable_str = resizable ? 'yes' : 'no';
  window.open(url, name, 'left='+left+',top='+top+',width='+width+',height='+height+',toolbar='+toolbar_str+',menubar='+menubar_str+',status='+statusbar_str+',scrollbars='+scrollbar_str+',resizable='+resizable_str);
}
//-->
</script>
<center>

<table align="center" width="90%" cellpadding="0" cellspacing="0" bgcolor="<?php echo $skin['image_table_bgcolor']; ?>">
<tr><td width="37">
<p align="center"><span style="font-size:9pt;">
<img src="skin/<?php echo $admin_data['skin']; ?>/info.jpg" width="32" height="32" alt="Info"></span></p>
</td>
<td align="center">
<p><span style="font-size:9pt;"><?php echo $search_type_str; ?>에 대한 검색어 <b><?php echo $search_word; ?></b>(으)로 <b><?php echo $fileidx; ?></b>개의 결과가 검색되었습니다. <b><a href="list.php">[목록으로 돌아가기]</a></b><br>현재 <?php echo $page; ?> 페이지 / 전체&nbsp;<?php echo $startpage; ?>&nbsp;페이지 (페이지당 <?php echo $admin_data['app']?>개씩 출력)</span></p>
</td>

<td width="37">
<p><span style="font-size:9pt;"><a href="#search"><img src="skin/<?php echo $admin_data['skin']?>/search.jpg" width="32" height="32" alt="검색" border="0"></a></span></p>
</td>

<?php
/* {{{ 관리자 로그인 상태 처리부분 */ 
    if ($admin['login']) {
?>

<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_config', 'config.php?from=<?php echo $page_this?>', 30, 30, 700, 610, 0, 0, 0, 1, 1)"><img src="skin/<?php echo $admin_data['skin']; ?>/config.jpg" width="32" height="32" alt="게시판 환경 설정" border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_iconman', 'iconman.php', 60, 60, 610, 400, 0, 0, 0, 1, 1)"><img src="skin/<?php echo $admin_data['skin']; ?>/addicon.jpg" width="32" height="32" alt="아이콘 관리자" border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="admin_logout.php?from=<?php echo rawurldecode($page_this); ?>"><img src="skin/<?php echo $admin_data['skin']; ?>/logout.jpg" width="32" height="32" alt="관리자 로그아웃" border="0"></a></span></p>
</td>

<?php } else { ?>

<td width="37">
 <p>
 <a href="javascript:Openwindow('hb_login', 'admin.php?from=<?php echo $page_this;?>', 50, 50, 360, 140, 0, 0, 0, 0, 0);"
  title="관리자 로그인"><img src="skin/<?php echo $admin_data['skin'];?>/login.jpg"
  width="32" height="32" alt="관리자 로그인" border="0"></a>
 </p>
</td>

<?php } /* }}} */ ?>

</tr></table>
<br>
<!-- {{{ 출력부분 시작 -->
<?php

    if($fileidx<=0) {
        echo "<center><br><font size=5>검색된 데이터가 없습니다.</font><br><br></center>\n";
    }
    else {

        // 아 쒸x.... 검색하면 idx가 순차적으로 있는게 아니군 -_-;;
        // 하는수없이 검색하면 과부하가 조금... -_-^
        for($i=$headart; $i<=$footart; $i++) {
            if(isset($search_residx[$i])) {
                PrintArticle($search_residx[$i], $search_residx[$i], true);
            }
        }

    }

    echo "현재 <b><font color=blue>" .$page ."</font></b> 페이지 <font color=green>/</font> 전체 <b><font color=red>" .$startpage ."</font></b> 페이지<br>";

    $search_word = rawurlencode($search_word);

    if($page>1) {
        echo "<a href=\"search.php?page=1&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\" title=\"첫 페이지\">|</a>&nbsp;<a href=\"search.php?page=" . ($page - 1) . "&amp;search_word={$search_word}&amp;search_type={$search_type}\" title=\"이전 페이지\">◁</a>&nbsp;&nbsp;";
    } else {
        echo "<font color=\"{$skin['image_table_bgcolor']}\"><a title=\"첫 페이지\">|</a>&nbsp;<a title=\"이전 페이지\">◁</a></font>&nbsp;&nbsp;";
    } // 이전 페이지랑 첫 페이지 버튼

    // 미친 for문 부분 시작
    for($pagecnt=($page-4);; $pagecnt++) {
        if($pagecnt<=0) { } // 페이지가 처음이면 do nothing;
        else if($pagecnt>=$page) {
            break; }
            else {
                echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\">[" .$pagecnt ."]</a>&nbsp;"; }
            }

            echo "[<b>" .$page ."</b>]&nbsp;";

            for($pagecnt=($page+1);; $pagecnt++) {

                if($page<=4) { // 첫 페이지라면?
                if($pagecnt>$startpage) { break; } // 끝에 닿으면 정지
                else if($pagecnt>=(($page+10)-$page)) { break; }
                else { echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\">[" .$pagecnt ."]</a>&nbsp;"; }
            }

            else { // 아님 말구 ㅡㅡ..
            if($pagecnt>$startpage) { break; } // 끝에 닿으면 정지
            else if($pagecnt>=($page+5)) { break; } // +5 도 정지
            else { echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\">[" .$pagecnt ."]</a>&nbsp;"; }
        }
    }

    // 미친 for문 부분 끝

    if(($fileidx/$page)<=$admin_data['app']) {
        echo "&nbsp;<font color=\"{$skin['image_table_bgcolor']}\"><a title=\"다음 페이지\">▷</a>&nbsp;<a title=\"마지막 페이지\">|</a></font>";
    } else {
        echo "&nbsp;<a href=\"search.php?page=" .($page+1) ."&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\" title=\"다음 페이지\">▷</a>&nbsp;<a href=\"search.php?page=" .$startpage ."&amp;search_word={$search_word}&amp;search_type={$_GET['search_type']}\" title=\"마지막 페이지\">|</a>";
    } // 다음 페이지랑 마지막 페이지 버튼..ㅡㅡ

    // 검색폼에서 미리 선택된 검색방식..
    /* E_NOTICE 처리 */
    $option['name'] = $option['subject'] = $option['ment'] = $option['cfile'] = '';

    if($_GET['search_type'] == "name") $option['name'] = " selected";
    else if($_GET['search_type'] == "subject") $option['subject'] = " selected";
    else if($_GET['search_type'] == "ment") $option['ment'] = " selected";
    else $option['cfile'] = " selected";
?>
<br>
<a name="search"></a>
<form name="searchform" action="search.php" method="get">
 <table width="314" align="center" cellpadding="0" cellspacing="0" bgcolor="<?php echo $skin['image_table_bgcolor']; ?>">
  <tr>
   <td width="18" height="37">
    <p align="center">
    <span style="font-size:9pt;">&nbsp;</span></p>
   </td>
   <td width="56" height="37">
    <p align="center">
    <span style="font-size:9pt;"><img src="skin/<?php echo $admin_data['skin']; ?>/search.jpg" width="32" height="32" alt="검색" border="0"></span></p>
   </td>
   <td width="79" height="37">
    <p align="center"><span style="font-size:9pt;">
     <select name="search_type" size="1">
      <option value="name"<?php echo $option['name']; ?>>작성자</option>
      <option value="subject"<?php echo $option['subject']; ?>>글 제목</option>
      <option value="ment"<?php echo $option['ment']; ?>>글 내용</option>
      <option value="cfile"<?php echo $option['cfile']; ?>>파일 이름</option>
    </select></span></p>
   </td>
   <td width="120" height="37">
    <p align="center"><span style="font-size:9pt;"><input type="text" name="search_word" maxlength="50" size="15" value="<?php echo rawurldecode($search_word); ?>"></span></p>
   </td>
   <td width="50" height="37">

    <p align="left">&nbsp;<span style="font-size:9pt;"><input type="button" name="search_go" value="검색" onclick="checksearch();"></span>
   </td>
   <td width="15" height="37">
    <p><span style="font-size:9pt;">&nbsp;</span></p>

   </td>
  </tr>
 </table>
</form>
<b><a href="list.php">[◁ 목록으로 돌아가기]</a></b>
<br>
<br>

<!-- }}} 출력부분 끝 -->

<?php
}
PrintFooter();
?>
